##  Syncing Associated Relations
Choosing a relation type from the LeanIX Relation drop-down list maps the relations between SAP Signavio processes and dictionary items to the corresponding business context/process fact sheets and associated fact sheets in SAP LeanIX.
For example, if you have synchronized processes from SAP Signavio as process fact sheets and applications from SAP LeanIX to SAP Signavio as dictionary items, the integration recognizes when a dictionary item is included in a process definition. It will then create a relation between the corresponding application fact sheet and the process fact sheet in SAP LeanIX. By selecting a relation type from the LeanIX Relation drop-down list, you specify what type of relation it should be. For the relation between applications and processes, select Business Context.
The relation between dictionary items and processes is always synchronized from SAP Signavio to SAP LeanIX, regardless of which system you have set as the source for each mapping. Since SAP Signavio acts as the source of truth for these relations, the synchronization is strict. This means any manually created or modified process relations in SAP LeanIX are either deleted or updated from SAP Signavio, given that those fact sheets and dictionary items are mapped.
**Note**
Required Permission
To retrieve the relations between processes and dictionary items, the SAP Signavio user account associated with the integration must have permission to read the entire dictionary. This is necessary even if not all dictionary categories are relevant for mapping fact sheets and dictionary items.
To learn more about required permissions, see [Minimum Access Rights for Integration](https://help.sap.com/docs/leanix/ea/configuring-integration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c64207a441014b145d1ff0fd5f0f5__minimum_access_rights_for_integration).
